@@ -7,6 +7,7 @@
 #' @param upper numeric: upper threshold
 #' @param spacing numeric 3D-vector: specifies the voxel dimensons in x,y,z direction.
 #' @param origin numeric 3D-vector: origin of the original data set, will transpose the mesh onto that origin.
+#' @param threshold threshold of intersecting the cube (default is 0.5).
 #' @return returns a triangular mesh of class "mesh3d"
 #' @examples
 #' #this is the example from the package "misc3d"
@@ -22,13 +23,15 @@
 #' wire3d(vcgSmooth(mesh,"HC",iteration=3),col=3)
 #' }
 #' @export
-vcgIsosurface <- function(vol,lower=min(vol),upper=max(vol),spacing=NULL, origin=NULL) {
+vcgIsosurface <- function(vol,lower=min(vol),upper=max(vol),spacing=NULL, origin=NULL,threshold=0.5) {
     if (length(dim(vol)) != 3)
         stop("3D array needed")
+    if (threshold < 0 || threshold >= 1)
+        stop("threshold must be >=0 and < 1")
     lower <- as.numeric(lower)
     upper <- as.numeric(upper)
     storage.mode(vol) <- "integer"
-    volmesh <- .Call("RMarchC",vol,lower,upper)
+    volmesh <- .Call("RMarchC",vol,lower,upper,threshold)
     volmesh$vb <- rbind(volmesh$vb,1)
     volmesh$it <- volmesh$it
     
